@@ -418,6 +418,10 @@ def add_colorbar(
     if "tick_font_size" in kwargs:
         tick_font_size = kwargs.pop("tick_font_size")
 
+    label_font_family = None
+    if "label_font_family" in kwargs:
+        label_font_family = kwargs.pop("label_font_family")
+
     label_font_size = None
     if "label_font_size" in kwargs:
         label_font_size = kwargs.pop("label_font_size")
@@ -427,8 +431,12 @@ def add_colorbar(
     if "bands" in vis_keys:
         cb.set_label(vis_params["bands"])
     elif label is not None:
-        if label_font_size is not None:
+        if label_font_size is not None and label_font_family is not None:
+            cb.set_label(label, fontsize=label_font_size, family=label_font_family)
+        elif label_font_size is not None and label_font_family is None:
             cb.set_label(label, fontsize=label_font_size)
+        elif label_font_size is None and label_font_family is not None:
+            cb.set_label(label, family=label_font_family)
         else:
             cb.set_label(label)
 
@@ -980,7 +988,7 @@ def add_scale_bar_lite(
             if str(x)[0] in ["1", "2", "5"]:
                 return int(x)
             else:
-                return scale_number(x - 10 ** ndim)
+                return scale_number(x - 10**ndim)
 
         length = scale_number(length)
         num = length
@@ -1006,7 +1014,15 @@ def add_scale_bar_lite(
     return
 
 
-def add_legend(ax, legend_elements=None, loc="lower right"):
+def add_legend(
+    ax,
+    legend_elements=None,
+    loc="lower right",
+    font_size=14,
+    font_weight='normal',
+    font_color='black',
+    font_family=None,
+):
     """Adds a legend to the map. The legend elements can be formatted as:
     legend_elements = [Line2D([], [], color='#00ffff', lw=2, label='Coastline'),
         Line2D([], [], marker='o', color='#A8321D', label='City', markerfacecolor='#A8321D', markersize=10, ls ='')]
@@ -1015,7 +1031,10 @@ def add_legend(ax, legend_elements=None, loc="lower right"):
         ax (cartopy.mpl.geoaxes.GeoAxesSubplot | cartopy.mpl.geoaxes.GeoAxes): required cartopy GeoAxesSubplot object.
         legend_elements (list, optional): A list of legend elements. Defaults to None.
         loc (str, optional): Location of the legend, can be any of ['upper left', 'upper right', 'lower left', 'lower right']. Defaults to "lower right".
-
+        font_size(int|string, optional): Font size. Either an absolute font size or an relative value of 'xx-small', 'x-small', 'small', 'medium', 'large', 'x-large', 'xx-large'. defaults to 14.
+        font_weight(string|int, optional): Font weight. A numeric value in the range 0-1000 or one of 'ultralight', 'light', 'normal' (default), 'regular', 'book', 'medium', 'roman', 'semibold', 'demibold', 'demi', 'bold', 'heavy', 'extra bold', 'black'. Defaults to 'normal'.
+        font_color(str, optional): Text color. Defaults to "black".
+        font_family(string, optional): Name of font family. Set to a font family like 'SimHei' if you want to show Chinese in the legend. Defaults to None.
     Raises:
         Exception: If the legend fails to add.
     """
@@ -1036,8 +1055,16 @@ def add_legend(ax, legend_elements=None, loc="lower right"):
                     ls="",
                 ),
             ]
+        if font_family is not None:
+            fontdict = {"family": font_family, "size": font_size, "weight": font_weight}
+        else:
+            fontdict = {"size": font_size, "weight": font_weight}
+        leg = ax.legend(handles=legend_elements, loc=loc, prop=fontdict)
 
-        ax.legend(handles=legend_elements, loc=loc)
+        # Change font color If default color is changed.
+        if font_color != 'black':
+            for text in leg.get_texts():
+                text.set_color(font_color)
         return
     except Exception as e:
         raise Exception(e)
@@ -1115,7 +1142,7 @@ def get_image_collection_gif(
         fig = plt.figure(figsize=fig_size)
 
         # Set the facecolor
-        fig.patch.set_facecolor('white')
+        fig.patch.set_facecolor("white")
 
         # Plot image
         ax = get_map(image, region=region, vis_params=vis_params, cmap=cmap, proj=proj)
@@ -1136,7 +1163,12 @@ def get_image_collection_gif(
             add_north_arrow(ax, **north_arrow_dict)
 
         # Save plot
-        plt.savefig(fname=out_img, dpi=dpi_plot, bbox_inches='tight', facecolor=fig.get_facecolor())
+        plt.savefig(
+            fname=out_img,
+            dpi=dpi_plot,
+            bbox_inches="tight",
+            facecolor=fig.get_facecolor(),
+        )
 
         plt.clf()
         plt.close()
