@@ -1,7 +1,7 @@
 """Module for creating charts for Earth Engine data.
 """
 
-# import ee
+import ee
 import pandas as pd
 from bqplot import Tooltip
 from bqplot import pyplot as plt
@@ -299,6 +299,16 @@ def feature_histogram(
     """
     import math
 
+    if not isinstance(features, ee.FeatureCollection):
+        raise Exception("features must be an ee.FeatureCollection")
+
+    first = features.first()
+    props = first.propertyNames().getInfo()
+    if property not in props:
+        raise Exception(
+            f"property {property} not found. Available properties: {', '.join(props)}"
+        )
+
     def nextPowerOf2(n):
         return pow(2, math.ceil(math.log2(n)))
 
@@ -428,7 +438,7 @@ def image_doySeries(
     yearReducer,
     startDay,
     endDay,
-    **kwargs
+    **kwargs,
 ):
     # TODO
     pass
@@ -444,7 +454,7 @@ def image_doySeriesByRegion(
     seriesProperty,
     startDay,
     endDay,
-    **kwargs
+    **kwargs,
 ):
     # TODO
     pass
@@ -459,7 +469,7 @@ def image_doySeriesByYear(
     sameDayReducer,
     startDay,
     endDay,
-    **kwargs
+    **kwargs,
 ):
     # TODO
     pass
