@@ -267,6 +267,8 @@ class Map(folium.Map):
         from box import Box
 
         image = None
+        if vis_params is None:
+            vis_params = {}
 
         if (
             not isinstance(ee_object, ee.Image)
@@ -545,35 +547,44 @@ class Map(folium.Map):
 
     def add_stac_layer(
         self,
-        url,
+        url=None,
+        collection=None,
+        item=None,
+        assets=None,
         bands=None,
-        name="Untitled",
+        titiler_endpoint=None,
+        name="STAC Layer",
         attribution=".",
         opacity=1.0,
         shown=True,
-        titiler_endpoint="https://titiler.xyz",
         **kwargs,
     ):
         """Adds a STAC TileLayer to the map.
 
         Args:
-            url (str): The URL of the COG tile layer.
-            name (str, optional): The layer name to use for the layer. Defaults to 'Untitled'.
-            attribution (str, optional): The attribution to use. Defaults to '.'.
+            url (str): HTTP URL to a STAC item, e.g., https://canada-spot-ortho.s3.amazonaws.com/canada_spot_orthoimages/canada_spot5_orthoimages/S5_2007/S5_11055_6057_20070622/S5_11055_6057_20070622.json
+            collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
+            item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
+            assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
+            bands (list): A list of band names, e.g., ["SR_B7", "SR_B5", "SR_B4"]
+            titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+            name (str, optional): The layer name to use for the layer. Defaults to 'STAC Layer'.
+            attribution (str, optional): The attribution to use. Defaults to ''.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
             shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
         """
-        tile_url = stac_tile(url, bands, titiler_endpoint, **kwargs)
-        center = stac_center(url, titiler_endpoint)
+        tile_url = stac_tile(
+            url, collection, item, assets, bands, titiler_endpoint, **kwargs
+        )
+        bounds = stac_bounds(url, collection, item, titiler_endpoint)
         self.add_tile_layer(
-            tiles=tile_url,
+            url=tile_url,
             name=name,
             attribution=attribution,
             opacity=opacity,
             shown=shown,
         )
-        self.set_center(lon=center[0], lat=center[1], zoom=10)
+        self.fit_bounds([[bounds[1], bounds[0]], [bounds[3], bounds[2]]])
 
     def add_legend(
         self,
@@ -922,7 +933,7 @@ class Map(folium.Map):
         name="Folium Map",
         description="",
         source_url="",
-        visibility="PUBLIC",
+        visibility="DEFAULT",
         open=True,
         tags=None,
         **kwargs,
@@ -933,7 +944,7 @@ class Map(folium.Map):
             name (str, optional): The document name - can include spaces, caps, symbols, etc., e.g. "Profit & Loss 2020". Defaults to "Folium Map".
             description (str, optional): A high-level description for the document, this is displayed in searches and thumbnails. Defaults to ''.
             source_url (str, optional): A URL pointing to the source code for the document, e.g. a GitHub repo or a Colab notebook. Defaults to ''.
-            visibility (str, optional): Visibility of the map. It can be one of the following: PUBLIC, PRIVATE. Defaults to 'PUBLIC'.
+            visibility (str, optional): Visibility of the map. It can be one of the following: PORTFOLIO, PRIVATE, DEFAULT. Defaults to 'DEFAULT'.
             open (bool, optional): Whether to open the map. Defaults to True.
             tags (bool, optional): A list of tags (as strings) used to categorise your document. Defaults to None.
         """
@@ -951,17 +962,19 @@ class Map(folium.Map):
 
             visibility = visibility.upper()
 
-            if visibility not in ["PUBLIC", "PRIVATE"]:
+            if visibility not in ["DEFAULT", "PRIVATE", "PORTFOLIO"]:
                 raise ValueError(
-                    "The visibility argument must be either PUBLIC or PRIVATE."
+                    "The visibility argument must be either DEFAULT or PRIVATE or PORTFOLIO."
                 )
 
-            if visibility == "PUBLIC":
-                visibility = dp.Visibility.PUBLIC
-            else:
+            if visibility == "PRIVATE":
                 visibility = dp.Visibility.PRIVATE
+            elif visibility == "PORTFOLIO":
+                visibility = dp.Visibility.PORTFOLIO
+            else:
+                visibility = dp.Visibility.DEFAULT
 
-            dp.Report(dp.Plot(self)).publish(
+            dp.Report(dp.Plot(self)).upload(
                 name=name,
                 description=description,
                 source_url=source_url,
