@@ -7,6 +7,10 @@ import folium
 from box import Box
 from folium import plugins
 
+from branca.element import Figure, JavascriptLink
+from folium.map import Layer
+from jinja2 import Template
+
 from .basemaps import xyz_to_folium
 from .common import *
 from .conversion import *
@@ -14,7 +18,8 @@ from .legends import builtin_legends
 from .osm import *
 from .timelapse import *
 
-folium_basemaps = Box(xyz_to_folium(), frozen_box=True)
+
+basemaps = Box(xyz_to_folium(), frozen_box=True)
 
 
 class Map(folium.Map):
@@ -62,27 +67,68 @@ class Map(folium.Map):
         if "add_google_map" not in kwargs.keys() and "basemap" not in kwargs.keys():
             kwargs["add_google_map"] = True
         if "plugin_LatLngPopup" not in kwargs.keys():
-            kwargs["plugin_LatLngPopup"] = True
+            kwargs["plugin_LatLngPopup"] = False
         if "plugin_Fullscreen" not in kwargs.keys():
             kwargs["plugin_Fullscreen"] = True
         if "plugin_Draw" not in kwargs.keys():
-            kwargs["plugin_Draw"] = False
+            kwargs["plugin_Draw"] = True
         if "Draw_export" not in kwargs.keys():
-            kwargs["Draw_export"] = True
+            kwargs["Draw_export"] = False
         if "plugin_MiniMap" not in kwargs.keys():
             kwargs["plugin_MiniMap"] = False
         if "plugin_LayerControl" not in kwargs.keys():
             kwargs["plugin_LayerControl"] = False
         if "locate_control" not in kwargs:
             kwargs["locate_control"] = False
+        if "search_control" not in kwargs:
+            kwargs["search_control"] = True
+
+        if (
+            "width" in kwargs
+            and isinstance(kwargs["width"], str)
+            and ("%" not in kwargs["width"])
+        ):
+            kwargs["width"] = float(kwargs["width"].replace("px", ""))
+
+        height = None
+        width = None
+
+        if "height" in kwargs:
+            height = kwargs.pop("height")
+
+        if "width" in kwargs:
+            width = kwargs.pop("width")
+        else:
+            width = "100%"
 
         super().__init__(**kwargs)
         self.baseclass = "folium"
 
+        # The number of shapes drawn by the user using the DrawControl
+        self.draw_count = 0
+        # The list of Earth Engine Geometry objects converted from geojson
+        self.draw_features = []
+        # The Earth Engine Geometry object converted from the last drawn feature
+        self.draw_last_feature = None
+        self.draw_layer = None
+        self.draw_last_json = None
+        self.draw_last_bounds = None
+        self.user_roi = None
+        self.user_rois = None
+        self.last_ee_data = None
+        self.last_ee_layer = None
+        self.search_locations = None
+        self.search_loc_marker = None
+        self.search_loc_geom = None
+
+        if (height is not None) or (width is not None):
+            f = folium.Figure(width=width, height=height)
+            self.add_to(f)
+
         if kwargs.get("add_google_map"):
-            folium_basemaps["ROADMAP"].add_to(self)
+            basemaps["ROADMAP"].add_to(self)
         if kwargs.get("basemap"):
-            folium_basemaps[kwargs.get("basemap")].add_to(self)
+            basemaps[kwargs.get("basemap")].add_to(self)
         if kwargs.get("plugin_LatLngPopup"):
             folium.LatLngPopup().add_to(self)
         if kwargs.get("plugin_Fullscreen"):
@@ -95,6 +141,8 @@ class Map(folium.Map):
             folium.LayerControl().add_to(self)
         if kwargs["locate_control"]:
             plugins.LocateControl().add_to(self)
+        if kwargs["search_control"]:
+            plugins.Geocoder(collapsed=True, position="topleft").add_to(self)
 
         self.fit_bounds([latlon, latlon], max_zoom=zoom)
 
@@ -107,11 +155,11 @@ class Map(folium.Map):
             types ([type], optional): A list of mapTypeIds to make available. If omitted, but opt_styles is specified, appends all of the style keys to the standard Google Maps API map types.. Defaults to None.
         """
         try:
-            folium_basemaps[mapTypeId].add_to(self)
+            basemaps[mapTypeId].add_to(self)
         except Exception:
             raise Exception(
                 "Basemap can only be one of the following: {}".format(
-                    ", ".join(folium_basemaps.keys())
+                    ", ".join(basemaps.keys())
                 )
             )
 
@@ -124,11 +172,11 @@ class Map(folium.Map):
             basemap (str, optional): Can be one of string from ee_basemaps. Defaults to 'HYBRID'.
         """
         try:
-            folium_basemaps[basemap].add_to(self)
+            basemaps[basemap].add_to(self)
         except Exception:
             raise Exception(
                 "Basemap can only be one of the following: {}".format(
-                    ", ".join(folium_basemaps.keys())
+                    ", ".join(basemaps.keys())
                 )
             )
 
@@ -154,6 +202,8 @@ class Map(folium.Map):
         from box import Box
 
         image = None
+        if vis_params is None:
+            vis_params = {}
 
         if (
             not isinstance(ee_object, ee.Image)
@@ -491,7 +541,7 @@ class Map(folium.Map):
         self,
         url=None,
         collection=None,
-        items=None,
+        item=None,
         assets=None,
         bands=None,
         titiler_endpoint=None,
@@ -506,7 +556,7 @@ class Map(folium.Map):
         Args:
             url (str): HTTP URL to a STAC item, e.g., https://canada-spot-ortho.s3.amazonaws.com/canada_spot_orthoimages/canada_spot5_orthoimages/S5_2007/S5_11055_6057_20070622/S5_11055_6057_20070622.json
             collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
-            items (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
+            item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
             assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
             bands (list): A list of band names, e.g., ["SR_B7", "SR_B5", "SR_B4"]
             titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
@@ -516,9 +566,9 @@ class Map(folium.Map):
             shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
         """
         tile_url = stac_tile(
-            url, collection, items, assets, bands, titiler_endpoint, **kwargs
+            url, collection, item, assets, bands, titiler_endpoint, **kwargs
         )
-        bounds = stac_bounds(url, collection, items, titiler_endpoint)
+        bounds = stac_bounds(url, collection, item, titiler_endpoint)
         self.add_tile_layer(
             url=tile_url,
             name=name,
@@ -569,6 +619,8 @@ class Map(folium.Map):
         tile.add_to(self)
         self.zoom_to_bounds(bounds)
 
+    add_geotiff = add_local_tile
+
     def add_remote_tile(
         self,
         source,
@@ -772,11 +824,9 @@ class Map(folium.Map):
 
     def add_colorbar(
         self,
-        colors,
-        vmin=0,
-        vmax=1.0,
+        vis_params,
         index=None,
-        caption="",
+        label="",
         categorical=False,
         step=None,
         **kwargs,
@@ -788,13 +838,28 @@ class Map(folium.Map):
             vmin (int, optional): The minimal value for the colormap. Values lower than vmin will be bound directly to colors[0].. Defaults to 0.
             vmax (float, optional): The maximal value for the colormap. Values higher than vmax will be bound directly to colors[-1]. Defaults to 1.0.
             index (list, optional):The values corresponding to each color. It has to be sorted, and have the same length as colors. If None, a regular grid between vmin and vmax is created.. Defaults to None.
-            caption (str, optional): The caption for the colormap. Defaults to "".
+            label (str, optional): The caption for the colormap. Defaults to "".
             categorical (bool, optional): Whether or not to create a categorical colormap. Defaults to False.
             step (int, optional): The step to split the LinearColormap into a StepColormap. Defaults to None.
         """
         from box import Box
         from branca.colormap import LinearColormap
 
+        if not isinstance(vis_params, dict):
+            raise ValueError("vis_params must be a dictionary.")
+
+        if "palette" not in vis_params:
+            raise ValueError("vis_params must contain a palette.")
+
+        if "min" not in vis_params:
+            vis_params["min"] = 0
+        if "max" not in vis_params:
+            vis_params["max"] = 1
+
+        colors = vis_params["palette"]
+        vmin = vis_params["min"]
+        vmax = vis_params["max"]
+
         if isinstance(colors, Box):
             try:
                 colors = list(colors["default"])
@@ -806,7 +871,7 @@ class Map(folium.Map):
             colors = ["#" + color for color in colors]
 
         colormap = LinearColormap(
-            colors=colors, index=index, vmin=vmin, vmax=vmax, caption=caption
+            colors=colors, index=index, vmin=vmin, vmax=vmax, caption=label
         )
 
         if categorical:
@@ -1318,6 +1383,13 @@ class Map(folium.Map):
         min_width=100,
         max_width=200,
         layer_name="Marker Cluster",
+        color_column=None,
+        marker_colors=None,
+        icon_colors=['white'],
+        icon_names=['info'],
+        angle=0,
+        prefix='fa',
+        add_legend=True,
         **kwargs,
     ):
         """Adds a marker cluster to the map.
@@ -1330,10 +1402,38 @@ class Map(folium.Map):
             min_width (int, optional): The minimum width of the popup. Defaults to 100.
             max_width (int, optional): The maximum width of the popup. Defaults to 200.
             layer_name (str, optional): The name of the layer. Defaults to "Marker Cluster".
-
+            color_column (str, optional): The column name for the color values. Defaults to None.
+            marker_colors (list, optional): A list of colors to be used for the markers. Defaults to None.
+            icon_colors (list, optional): A list of colors to be used for the icons. Defaults to ['white'].
+            icon_names (list, optional): A list of names to be used for the icons. More icons can be found at https://fontawesome.com/v4/icons or https://getbootstrap.com/docs/3.3/components/?utm_source=pocket_mylist. Defaults to ['info'].
+            angle (int, optional): The angle of the icon. Defaults to 0.
+            prefix (str, optional): The prefix states the source of the icon. 'fa' for font-awesome or 'glyphicon' for bootstrap 3. Defaults to 'fa'.
+            add_legend (bool, optional): If True, a legend will be added to the map. Defaults to True.
         """
         import pandas as pd
 
+        color_options = [
+            'red',
+            'blue',
+            'green',
+            'purple',
+            'orange',
+            'darkred',
+            'lightred',
+            'beige',
+            'darkblue',
+            'darkgreen',
+            'cadetblue',
+            'darkpurple',
+            'white',
+            'pink',
+            'lightblue',
+            'lightgreen',
+            'gray',
+            'black',
+            'lightgray',
+        ]
+
         if isinstance(data, pd.DataFrame):
             df = data
         elif not data.startswith("http") and (not os.path.exists(data)):
@@ -1343,6 +1443,45 @@ class Map(folium.Map):
 
         col_names = df.columns.values.tolist()
 
+        if color_column is not None and color_column not in col_names:
+            raise ValueError(
+                f"The color column {color_column} does not exist in the dataframe."
+            )
+
+        if color_column is not None:
+            items = list(set(df[color_column]))
+        else:
+            items = None
+
+        if color_column is not None and marker_colors is None:
+            if len(items) > len(color_options):
+                raise ValueError(
+                    f"The number of unique values in the color column {color_column} is greater than the number of available colors."
+                )
+            else:
+                marker_colors = color_options[: len(items)]
+        elif color_column is not None and marker_colors is not None:
+            if len(items) != len(marker_colors):
+                raise ValueError(
+                    f"The number of unique values in the color column {color_column} is not equal to the number of available colors."
+                )
+
+        if items is not None:
+
+            if len(icon_colors) == 1:
+                icon_colors = icon_colors * len(items)
+            elif len(items) != len(icon_colors):
+                raise ValueError(
+                    f"The number of unique values in the color column {color_column} is not equal to the number of available colors."
+                )
+
+            if len(icon_names) == 1:
+                icon_names = icon_names * len(items)
+            elif len(items) != len(icon_names):
+                raise ValueError(
+                    f"The number of unique values in the color column {color_column} is not equal to the number of available colors."
+                )
+
         if popup is None:
             popup = col_names
 
@@ -1357,20 +1496,33 @@ class Map(folium.Map):
         for row in df.itertuples():
             html = ""
             for p in popup:
-                html = (
-                    html
-                    + "<b>"
-                    + p
-                    + "</b>"
-                    + ": "
-                    + str(eval(str("row." + p)))
-                    + "<br>"
-                )
+                html = html + "<b>" + p + "</b>" + ": " + str(getattr(row, p)) + "<br>"
             popup_html = folium.Popup(html, min_width=min_width, max_width=max_width)
+
+            if items is not None:
+                index = items.index(getattr(row, color_column))
+                marker_icon = folium.Icon(
+                    color=marker_colors[index],
+                    icon_color=icon_colors[index],
+                    icon=icon_names[index],
+                    angle=angle,
+                    prefix=prefix,
+                )
+            else:
+                marker_icon = None
+
             folium.Marker(
-                location=[eval(f"row.{y}"), eval(f"row.{x}")], popup=popup_html
+                location=[getattr(row, y), getattr(row, x)],
+                popup=popup_html,
+                icon=marker_icon,
             ).add_to(marker_cluster)
 
+        if items is not None and add_legend:
+            marker_colors = [check_color(c) for c in marker_colors]
+            self.add_legend(
+                title=color_column.title(), colors=marker_colors, labels=items
+            )
+
     def add_circle_markers_from_xy(
         self,
         data,
@@ -1410,7 +1562,7 @@ class Map(folium.Map):
         if "color" not in kwargs:
             kwargs["color"] = None
         if "fill" not in kwargs:
-            fill = True
+            kwargs["fill"] = True
         if "fill_color" not in kwargs:
             kwargs["fill_color"] = "blue"
         if "fill_opacity" not in kwargs:
@@ -1432,7 +1584,7 @@ class Map(folium.Map):
         if y not in col_names:
             raise ValueError(f"y must be one of the following: {', '.join(col_names)}")
 
-        for row in df.itertuples():
+        for _ in df.itertuples():
             html = ""
             for p in popup:
                 html = (
@@ -1585,21 +1737,23 @@ class Map(folium.Map):
 
     def to_streamlit(
         self,
-        width=700,
-        height=500,
+        width=1000,
+        height=650,
         responsive=True,
         scrolling=False,
         add_layer_control=True,
+        bidirectional=False,
         **kwargs,
     ):
         """Renders `folium.Figure` or `folium.Map` in a Streamlit app. This method is a static Streamlit Component, meaning, no information is passed back from Leaflet on browser interaction.
 
         Args:
-            width (int, optional): Width of the map. Defaults to 800.
-            height (int, optional): Height of the map. Defaults to 600.
+            width (int, optional): Width of the map. Defaults to 1000.
+            height (int, optional): Height of the map. Defaults to 650.
             responsive (bool, optional): Whether to make the map responsive. Defaults to True.
             scrolling (bool, optional): Whether to allow the map to scroll. Defaults to False.
             add_layer_control (bool, optional): Whether to add the layer control. Defaults to True.
+            bidirectional (bool, optional): Whether to add bidirectional functionality to the map. The streamlit-folium package is required to use the bidirectional functionality. Defaults to False.
 
         Raises:
             ImportError: If streamlit is not installed.
@@ -1615,20 +1769,119 @@ class Map(folium.Map):
             if add_layer_control:
                 self.add_layer_control()
 
-            if responsive:
-                make_map_responsive = """
-                <style>
-                [title~="st.iframe"] { width: 100%}
-                </style>
-                """
-                st.markdown(make_map_responsive, unsafe_allow_html=True)
-            return components.html(
-                self.to_html(), width=width, height=height, scrolling=scrolling
-            )
+            if bidirectional:
+                from streamlit_folium import st_folium
+
+                output = st_folium(self, width=width, height=height)
+                return output
+            else:
+
+                if responsive:
+                    make_map_responsive = """
+                    <style>
+                    [title~="st.iframe"] { width: 100%}
+                    </style>
+                    """
+                    st.markdown(make_map_responsive, unsafe_allow_html=True)
+                return components.html(
+                    self.to_html(), width=width, height=height, scrolling=scrolling
+                )
 
         except Exception as e:
             raise Exception(e)
 
+    def st_map_center(self, st_component):
+        """Get the center of the map.
+
+        Args:
+            st_folium (streamlit-folium): The streamlit component.
+
+        Returns:
+            tuple: The center of the map.
+        """
+
+        bounds = st_component["bounds"]
+        west = bounds["_southWest"]["lng"]
+        south = bounds["_southWest"]["lat"]
+        east = bounds["_northEast"]["lng"]
+        north = bounds["_northEast"]["lat"]
+        return (south + (north - south) / 2, west + (east - west) / 2)
+
+    def st_map_bounds(self, st_component):
+        """Get the bounds of the map in the format of (miny, minx, maxy, maxx).
+
+        Args:
+            st_folium (streamlit-folium): The streamlit component.
+
+        Returns:
+            tuple: The bounds of the map.
+        """
+
+        bounds = st_component["bounds"]
+        south = bounds["_southWest"]["lat"]
+        west = bounds["_southWest"]["lng"]
+        north = bounds["_northEast"]["lat"]
+        east = bounds["_northEast"]["lng"]
+
+        bounds = [[south, west], [north, east]]
+        return bounds
+
+    def st_fit_bounds(self):
+        """Fit the map to the bounds of the map.
+
+        Returns:
+            folium.Map: The map.
+        """
+
+        try:
+            import streamlit as st
+
+            if "map_bounds" in st.session_state:
+
+                bounds = st.session_state["map_bounds"]
+
+                self.fit_bounds(bounds)
+
+        except Exception as e:
+            raise Exception(e)
+
+    def st_last_draw(self, st_component):
+        """Get the last draw feature of the map.
+
+        Args:
+            st_folium (streamlit-folium): The streamlit component.
+
+        Returns:
+            str: The last draw of the map.
+        """
+
+        return st_component["last_active_drawing"]
+
+    def st_last_click(self, st_component):
+        """Get the last click feature of the map.
+
+        Args:
+            st_folium (streamlit-folium): The streamlit component.
+
+        Returns:
+            str: The last click of the map.
+        """
+
+        coords = st_component["last_clicked"]
+        return (coords["lat"], coords["lng"])
+
+    def st_draw_features(self, st_component):
+        """Get the draw features of the map.
+
+        Args:
+            st_folium (streamlit-folium): The streamlit component.
+
+        Returns:
+            list: The draw features of the map.
+        """
+
+        return st_component["all_drawings"]
+
     def add_census_data(self, wms, layer, census_dict=None, **kwargs):
         """Adds a census data layer to the map.
 
@@ -1752,8 +2005,9 @@ class Map(folium.Map):
                     df = gpd.read_file(data)
                     df[x] = df.centroid.x
                     df[y] = df.centroid.y
-                except:
+                except Exception as e:
                     print("geopandas is required to read geojson.")
+                    print(e)
                     return
         else:
             raise ValueError("data must be a DataFrame or an ee.FeatureCollection.")
@@ -1767,7 +2021,7 @@ class Map(folium.Map):
 
         try:
             size = int(font_size.replace("pt", ""))
-        except:
+        except Exception as _:
             raise ValueError("font_size must be something like '10pt'")
 
         layer_group = folium.FeatureGroup(name=layer_name)
@@ -1786,10 +2040,252 @@ class Map(folium.Map):
 
         layer_group.add_to(self)
 
+    def split_map(self, left_layer="TERRAIN", right_layer="OpenTopoMap", **kwargs):
+        """Adds a split-panel map.
+
+        Args:
+            left_layer (str, optional): The layer tile layer. Defaults to 'TERRAIN'.
+            right_layer (str, optional): The right tile layer. Defaults to 'OpenTopoMap'.
+        """
+        try:
+            if left_layer in basemaps.keys():
+                left_layer = basemaps[left_layer]
+            elif isinstance(left_layer, str):
+                if left_layer.startswith("http") and left_layer.endswith(".tif"):
+                    url = cog_tile(left_layer)
+                    left_layer = folium.raster_layers.TileLayer(
+                        tiles=url,
+                        name="Left Layer",
+                        attr=" ",
+                        overlay=True,
+                    )
+                else:
+                    left_layer = folium.raster_layers.TileLayer(
+                        tiles=left_layer,
+                        name="Left Layer",
+                        attr=" ",
+                        overlay=True,
+                    )
+            elif isinstance(left_layer, folium.raster_layers.TileLayer) or isinstance(
+                left_layer, folium.WmsTileLayer
+            ):
+                pass
+            else:
+                raise ValueError(
+                    f"left_layer must be one of the following: {', '.join(basemaps.keys())} or a string url to a tif file."
+                )
+
+            if right_layer in basemaps.keys():
+                right_layer = basemaps[right_layer]
+            elif isinstance(right_layer, str):
+                if right_layer.startswith("http") and right_layer.endswith(".tif"):
+                    url = cog_tile(right_layer)
+                    right_layer = folium.raster_layers.TileLayer(
+                        tiles=url,
+                        name="Right Layer",
+                        attr=" ",
+                        overlay=True,
+                    )
+                else:
+                    right_layer = folium.raster_layers.TileLayer(
+                        tiles=right_layer,
+                        name="Right Layer",
+                        attr=" ",
+                        overlay=True,
+                    )
+            elif isinstance(right_layer, folium.raster_layers.TileLayer) or isinstance(
+                left_layer, folium.WmsTileLayer
+            ):
+                pass
+            else:
+                raise ValueError(
+                    f"right_layer must be one of the following: {', '.join(basemaps.keys())} or a string url to a tif file."
+                )
+
+            control = SplitControl(
+                layer_left=left_layer, layer_right=right_layer, name="Split Control"
+            )
+            left_layer.add_to(self)
+            right_layer.add_to(self)
+            control.add_to(self)
+
+        except Exception as e:
+            print("The provided layers are invalid!")
+            raise ValueError(e)
+
+    def add_netcdf(
+        self,
+        filename,
+        variables=None,
+        palette=None,
+        vmin=None,
+        vmax=None,
+        nodata=None,
+        attribution=None,
+        layer_name="NetCDF layer",
+        shift_lon=True,
+        lat="lat",
+        lon="lon",
+        **kwargs,
+    ):
+        """Generate an ipyleaflet/folium TileLayer from a netCDF file.
+            If you are using this function in JupyterHub on a remote server (e.g., Binder, Microsoft Planetary Computer),
+            try adding to following two lines to the beginning of the notebook if the raster does not render properly.
+
+            import os
+            os.environ['LOCALTILESERVER_CLIENT_PREFIX'] = f'{os.environ['JUPYTERHUB_SERVICE_PREFIX'].lstrip('/')}/proxy/{{port}}'
+
+        Args:
+            filename (str): File path or HTTP URL to the netCDF file.
+            variables (int, optional): The variable/band names to extract data from the netCDF file. Defaults to None. If None, all variables will be extracted.
+            port (str, optional): The port to use for the server. Defaults to "default".
+            palette (str, optional): The name of the color palette from `palettable` to use when plotting a single band. See https://jiffyclub.github.io/palettable. Default is greyscale
+            vmin (float, optional): The minimum value to use when colormapping the palette when plotting a single band. Defaults to None.
+            vmax (float, optional): The maximum value to use when colormapping the palette when plotting a single band. Defaults to None.
+            nodata (float, optional): The value from the band to use to interpret as not valid data. Defaults to None.
+            attribution (str, optional): Attribution for the source raster. This defaults to a message about it being a local file.. Defaults to None.
+            layer_name (str, optional): The layer name to use. Defaults to "netCDF layer".
+            shift_lon (bool, optional): Flag to shift longitude values from [0, 360] to the range [-180, 180]. Defaults to True.
+            lat (str, optional): Name of the latitude variable. Defaults to 'lat'.
+            lon (str, optional): Name of the longitude variable. Defaults to 'lon'.
+        """
+
+        tif, vars = netcdf_to_tif(
+            filename, shift_lon=shift_lon, lat=lat, lon=lon, return_vars=True
+        )
+
+        if variables is None:
+            if len(vars) >= 3:
+                band_idx = [1, 2, 3]
+            else:
+                band_idx = [1]
+        else:
+            if not set(variables).issubset(set(vars)):
+                raise ValueError(f"The variables must be a subset of {vars}.")
+            else:
+                band_idx = [vars.index(v) + 1 for v in variables]
+
+        self.add_local_tile(
+            tif,
+            band=band_idx,
+            palette=palette,
+            vmin=vmin,
+            vmax=vmax,
+            nodata=nodata,
+            attribution=attribution,
+            layer_name=layer_name,
+            **kwargs,
+        )
+
     def remove_labels(self, **kwargs):
         """Removes a layer from the map."""
         print("The folium plotting backend does not support removing labels.")
 
+    def basemap_demo(self):
+        """A demo for using geemap basemaps."""
+        print("The folium plotting backend does not support this function.")
+
+    def set_plot_options(
+        self,
+        **kwargs,
+    ):
+        """Sets plotting options."""
+        print("The folium plotting backend does not support this function.")
+
+    def ts_inspector(
+        self,
+        left_ts,
+        right_ts,
+        left_names,
+        right_names,
+        left_vis={},
+        right_vis={},
+        width="130px",
+        **kwargs,
+    ):
+        print("The folium plotting backend does not support this function.")
+
+    def add_time_slider(
+        self,
+        ee_object,
+        vis_params={},
+        region=None,
+        layer_name="Time series",
+        labels=None,
+        time_interval=1,
+        position="bottomright",
+        slider_length="150px",
+        date_format="YYYY-MM-dd",
+        opacity=1.0,
+        **kwargs,
+    ):
+        print("The folium plotting backend does not support this function.")
+
+    def extract_values_to_points(self, filename):
+        print("The folium plotting backend does not support this function.")
+
+
+class SplitControl(Layer):
+    """
+    Creates a SplitControl that takes two Layers and adds a sliding control with the leaflet-side-by-side plugin.
+    Uses the Leaflet leaflet-side-by-side plugin https://github.com/digidem/leaflet-side-by-side Parameters.
+    The source code is adapted from https://github.com/python-visualization/folium/pull/1292
+    ----------
+    layer_left: Layer.
+        The left Layer within the side by side control.
+        Must  be created and added to the map before being passed to this class.
+    layer_right: Layer.
+        The left Layer within the side by side control.
+        Must  be created and added to the map before being passed to this class.
+    name : string, default None
+        The name of the Layer, as it will appear in LayerControls.
+    overlay : bool, default True
+        Adds the layer as an optional overlay (True) or the base layer (False).
+    control : bool, default True
+        Whether the Layer will be included in LayerControls.
+    show: bool, default True
+        Whether the layer will be shown on opening (only for overlays).
+    Examples
+    --------
+    >>> sidebyside = SideBySideLayers(layer_left, layer_right)
+    >>> sidebyside.add_to(m)
+    """
+
+    _template = Template(
+        """
+        {% macro script(this, kwargs) %}
+            var {{ this.get_name() }} = L.control.sideBySide(
+                {{ this.layer_left.get_name() }}, {{ this.layer_right.get_name() }}
+            ).addTo({{ this._parent.get_name() }});
+        {% endmacro %}
+        """
+    )
+
+    def __init__(
+        self, layer_left, layer_right, name=None, overlay=True, control=True, show=True
+    ):
+        super(SplitControl, self).__init__(
+            name=name, overlay=overlay, control=control, show=show
+        )
+        self._name = "SplitControl"
+        self.layer_left = layer_left
+        self.layer_right = layer_right
+
+    def render(self, **kwargs):
+        super(SplitControl, self).render()
+
+        figure = self.get_root()
+        assert isinstance(figure, Figure), (
+            "You cannot render this Element " "if it is not in a Figure."
+        )
+
+        figure.header.add_child(
+            JavascriptLink(
+                "https://raw.githack.com/digidem/leaflet-side-by-side/gh-pages/leaflet-side-by-side.js"
+            ),  # noqa
+            name="leaflet.sidebyside",
+        )
+
 
 def delete_dp_report(name):
     """Deletes a datapane report.
@@ -1828,3 +2324,136 @@ def delete_dp_reports():
     except Exception as e:
         print(e)
         return
+
+
+def ee_tile_layer(
+    ee_object, vis_params={}, name="Layer untitled", shown=True, opacity=1.0, **kwargs
+):
+    """Converts and Earth Engine layer to ipyleaflet TileLayer.
+
+    Args:
+        ee_object (Collection|Feature|Image|MapId): The object to add to the map.
+        vis_params (dict, optional): The visualization parameters. Defaults to {}.
+        name (str, optional): The name of the layer. Defaults to 'Layer untitled'.
+        shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
+        opacity (float, optional): The layer's opacity represented as a number between 0 and 1. Defaults to 1.
+    """
+
+    image = None
+
+    if (
+        not isinstance(ee_object, ee.Image)
+        and not isinstance(ee_object, ee.ImageCollection)
+        and not isinstance(ee_object, ee.FeatureCollection)
+        and not isinstance(ee_object, ee.Feature)
+        and not isinstance(ee_object, ee.Geometry)
+    ):
+        err_str = "\n\nThe image argument in 'addLayer' function must be an instance of one of ee.Image, ee.Geometry, ee.Feature or ee.FeatureCollection."
+        raise AttributeError(err_str)
+
+    if (
+        isinstance(ee_object, ee.geometry.Geometry)
+        or isinstance(ee_object, ee.feature.Feature)
+        or isinstance(ee_object, ee.featurecollection.FeatureCollection)
+    ):
+        features = ee.FeatureCollection(ee_object)
+
+        width = 2
+
+        if "width" in vis_params:
+            width = vis_params["width"]
+
+        color = "000000"
+
+        if "color" in vis_params:
+            color = vis_params["color"]
+
+        image_fill = features.style(**{"fillColor": color}).updateMask(
+            ee.Image.constant(0.5)
+        )
+        image_outline = features.style(
+            **{"color": color, "fillColor": "00000000", "width": width}
+        )
+
+        image = image_fill.blend(image_outline)
+    elif isinstance(ee_object, ee.image.Image):
+        image = ee_object
+    elif isinstance(ee_object, ee.imagecollection.ImageCollection):
+        image = ee_object.mosaic()
+
+    map_id_dict = ee.Image(image).getMapId(vis_params)
+    tile_layer = folium.raster_layers.TileLayer(
+        tiles=map_id_dict["tile_fetcher"].url_format,
+        attr="Google Earth Engine",
+        name=name,
+        overlay=True,
+        control=True,
+        opacity=opacity,
+        show=shown,
+        max_zoom=24,
+        **kwargs,
+    )
+    return tile_layer
+
+
+def st_map_center(lat, lon):
+    """Returns the map center coordinates for a given latitude and longitude. If the system variable 'map_center' exists, it is used. Otherwise, the default is returned.
+
+    Args:
+        lat (float): Latitude.
+        lon (float): Longitude.
+
+    Raises:
+        Exception: If streamlit is not installed.
+
+    Returns:
+        list: The map center coordinates.
+    """
+    try:
+        import streamlit as st
+
+        if "map_center" in st.session_state:
+            return st.session_state["map_center"]
+        else:
+            return [lat, lon]
+
+    except Exception as e:
+        raise Exception(e)
+
+
+def st_save_bounds(st_component):
+    """Saves the map bounds to the session state.
+
+    Args:
+        map (folium.folium.Map): The map to save the bounds from.
+    """
+    try:
+        import streamlit as st
+
+        if st_component is not None:
+            bounds = st_component["bounds"]
+            south = bounds["_southWest"]["lat"]
+            west = bounds["_southWest"]["lng"]
+            north = bounds["_northEast"]["lat"]
+            east = bounds["_northEast"]["lng"]
+
+            bounds = [[south, west], [north, east]]
+            center = [south + (north - south) / 2, west + (east - west) / 2]
+
+            st.session_state["map_bounds"] = bounds
+            st.session_state["map_center"] = center
+    except Exception as e:
+        raise Exception(e)
+
+
+def linked_maps(
+    rows=2,
+    cols=2,
+    height="400px",
+    ee_objects=[],
+    vis_params=[],
+    labels=[],
+    label_position="topright",
+    **kwargs,
+):
+    print("The folium plotting backend does not support this function.")
