@@ -1,5 +1,5 @@
 """
-This module defines here-map-widget-for-jupyter as backend for leafmap library.
+This module defines here-map-widget-for-jupyter as backend for geemap library.
 For more details about Here Map Widget for Jupyter
 please check: https://github.com/heremaps/here-map-widget-for-jupyter
 """
@@ -8,11 +8,24 @@ import os
 import json
 import random
 import requests
-import here_map_widget
 import ipywidgets as widgets
 from box import Box
 from .basemaps import xyz_to_heremap
-from .common import ee_initialize, shp_to_geojson, gdf_to_geojson, vector_to_geojson, random_string
+from .common import (
+    ee_initialize,
+    shp_to_geojson,
+    gdf_to_geojson,
+    vector_to_geojson,
+    random_string,
+)
+
+try:
+    import here_map_widget
+except ImportError:
+    raise ImportError(
+        'This module requires the hermap package. Please install it using "pip install here-map-widget-for-jupyter".'
+    )
+
 
 from here_map_widget import (
     FullscreenControl,
@@ -28,7 +41,7 @@ from here_map_widget import (
 )
 
 
-here_basemaps = Box(xyz_to_heremap(), frozen_box=True)
+basemaps = Box(xyz_to_heremap(), frozen_box=True)
 
 
 class Map(here_map_widget.Map):
@@ -65,7 +78,7 @@ class Map(here_map_widget.Map):
             kwargs["zoom"] = 2
 
         if "basemap" in kwargs:
-            kwargs["basemap"] = here_basemaps[kwargs["basemap"]]
+            kwargs["basemap"] = basemaps[kwargs["basemap"]]
 
         super().__init__(api_key=api_key, **kwargs)
         self.baseclass = "here_map_widget"
@@ -150,12 +163,12 @@ class Map(here_map_widget.Map):
                     )
                 )
                 self.basemap = layer
-            elif basemap in here_basemaps and here_basemaps[basemap] not in self.layers:
-                self.basemap = here_basemaps[basemap]
+            elif basemap in basemaps and basemaps[basemap] not in self.layers:
+                self.basemap = basemaps[basemap]
         except Exception:
             raise ValueError(
                 "Basemap can only be one of the following:\n  {}".format(
-                    "\n  ".join(here_basemaps.keys())
+                    "\n  ".join(basemaps.keys())
                 )
             )
 
@@ -204,6 +217,10 @@ class Map(here_map_widget.Map):
         from box import Box
 
         image = None
+
+        if vis_params is None:
+            vis_params = {}
+
         if name is None:
             layer_count = len(self.layout.mapbox.layers)
             name = "Layer " + str(layer_count + 1)
@@ -257,8 +274,9 @@ class Map(here_map_widget.Map):
 
         map_id_dict = ee.Image(image).getMapId(vis_params)
         url = map_id_dict["tile_fetcher"].url_format
-        self.add_tile_layer(url, name=name, attribution="Google Earth Engine",
-                            opacity=opacity, **kwargs)
+        self.add_tile_layer(
+            url, name=name, attribution="Google Earth Engine", opacity=opacity, **kwargs
+        )
 
     addLayer = add_ee_layer
 
